@@ -94,7 +94,7 @@ OneSampleCTest <- function(initialSample, mu_0,
 
   # checking numberOfSamples parameter
 
-  if(!isInteger(numberOfSamples) | numberOfSamples <= 1)
+  if(!ifInteger(numberOfSamples) | numberOfSamples <= 1)
   {
     stop("Parameter numberOfSamples should be integer value and > 1")
   }
